@@ -5,6 +5,7 @@ import pandas as pd
 import sqlite3
 import random
 import os
+import argparse
 
 from .parser import parse_fasta
 from .preprocessor import Preprocessor
@@ -31,7 +32,6 @@ class Matcher(Preprocessor):
                split=0,
                preprocessed_files_path='.',
                best_match=False,
-               output_df=True,
                output_format='csv',
                output_name=''):
 
@@ -54,7 +54,6 @@ class Matcher(Preprocessor):
     self.max_mismatches = max_mismatches
     self.preprocessed_files_path = preprocessed_files_path
     self.best_match = best_match
-    self.output_df = output_df
     self.output_format = output_format
 
     # use sql format for exact matches
@@ -128,10 +127,11 @@ class Matcher(Preprocessor):
     peptides = self.query
     all_matches_dict = {}
 
-    count = 0 
+    peptide_counter = 0 
     for peptide in peptides:
 
-      print('Searching peptide #%s' % str(count+1))
+      peptide_counter += 1
+      print('Searching peptide #%s' % str(peptide_counter))
 
       # skip peptide if shorter than the actual k-mer size
       if len(peptide) < self.split:
@@ -202,8 +202,6 @@ class Matcher(Preprocessor):
           if count == len(peptide) // self.split + 1:
             all_matches_dict[peptide].append(hit)
 
-      count+=1
-
     all_matches = []
 
     # compile all matches into format used for benchmarking (comma separated)
@@ -414,10 +412,12 @@ class Matcher(Preprocessor):
       kmer_dict, names_dict = self.read_pickle_files()
       rev_kmer_dict = {i: k for k, v in kmer_dict.items() for i in v}
 
-    count = 0
+    peptide_counter = 0
     for peptide in peptides:
 
-      print('Searching peptide #%s' % str(count+1))
+      peptide_counter += 1
+
+      print('Searching peptide #%s' % str(peptide_counter))
 
       # split peptide into all possible k-mers with size k (self.split)
       kmers = self.split_peptide(peptide, self.split)
@@ -431,7 +431,7 @@ class Matcher(Preprocessor):
         matches = self.uneven_split_mismatching(kmers, kmer_dict, rev_kmer_dict, len(peptide))
 
       all_matches_dict[peptide] = list(matches)
-      count+=1
+
 
     all_matches = []
 
@@ -495,7 +495,7 @@ class Matcher(Preprocessor):
       # separate out peptides that did not match into a new query
       self.query = []
       for match in matches:
-        if match[1] != '':
+        if match[1]:
           all_matches.append(match)
         else:
           self.query.append(match[0])
@@ -510,7 +510,7 @@ class Matcher(Preprocessor):
       # separate out peptides that did not match into a new query
       self.query = []
       for match in matches:
-        if match[1] != '':
+        if match[1]:
           all_matches.append(match)
         else:
           self.query.append(match[0])
@@ -544,24 +544,22 @@ class Matcher(Preprocessor):
     else:
       raise ValueError('Invalid input of mismatches.')
 
-    # option to output results to a specified format, default is CSV
-    if self.output_df:
-      if self.max_mismatches == 0:
-        df = self.dataframe_exact_matches(all_matches)
-      else:
-        df = self.dataframe_mismatch_matches(all_matches)
+    if self.max_mismatches == 0:
+      df = self.dataframe_exact_matches(all_matches)
+    else:
+      df = self.dataframe_mismatch_matches(all_matches)
 
-      if self.output_format == 'dataframe':
-        return df
-      else:
-        self.output_matches(df)
+    if self.output_format == 'dataframe':
+      return df
+    else:
+      self.output_matches(df)
 
-    return all_matches
+    return df
 
   def dataframe_exact_matches(self, all_matches):
     '''Return Pandas dataframe of the results.'''
     df = pd.DataFrame(all_matches,
-                      columns=['Peptide Sequence', 'Matched Sequence', 'Taxon ID',
+                      columns=['Peptide Sequence', 'Matched Sequence', 'Proteome',
                                'Species', 'Gene', 'Protein ID', 'Protein Name',
                                'Mismatches', 'Index start', 'Index end',
                                'Protein Existence Level', 'Gene Priority'])
@@ -593,7 +591,7 @@ class Matcher(Preprocessor):
   def dataframe_mismatch_matches(self, all_matches):
     '''Return Pandas dataframe of the results.'''
     df = pd.DataFrame(all_matches,
-                      columns=['Peptide Sequence', 'Matched Sequence', 'Taxon ID',
+                      columns=['Peptide Sequence', 'Matched Sequence', 'Proteome',
                                'Species', 'Gene', 'Protein ID', 'Protein Name',
                                'Mismatches', 'Mutated Positions', 'Index start',
                                'Index end', 'Protein Existence Level', 'Gene Priority'])
@@ -636,3 +634,28 @@ class Matcher(Preprocessor):
       return df.to_json(self.output_name + '.json')
     elif self.output_format == 'html':
       return df.to_html()
+
+
+# run via command line
+
+def parse_arguments():
+  parser = argparse.ArgumentParser()
+
+  parser.add_argument('-q', '--query', required=True)
+  parser.add_argument('-p', '--proteome', required=True)
+  parser.add_argument('-m', '--max_mismatches', type=int, required=True)
+  parser.add_argument('-k', '--kmer_size', type=int, required=True)
+  parser.add_argument('-P', '--preprocessed_files_path', default='.')
+  parser.add_argument('-b', '--best_match', type=bool, default=False)
+  parser.add_argument('-f', '--output_format', default='csv')
+  parser.add_argument('-o', '--output_name', default='')
+
+  args = parser.parse_args()
+
+  return args
+
+def run():
+  args = parse_arguments()
+
+  Matcher(args.query, args.proteome, args.max_mismatches, args.kmer_size, args.preprocessed_files_path, 
+          args.best_match, args.output_format, args.output_name).match()
